@@ -2,10 +2,10 @@ package net.reduls.igo;
 
 public final class Morpheme {
     public final String surface;
-    public final String info;
+    public final String feature;
     
-    public Morpheme(String s, String i) {
+    public Morpheme(String s, String f) {
 	surface = s;
-	info    = i;
+	feature = f;
     }
 }
\ No newline at end of file
