@@ -29,7 +29,7 @@ public final class Igo {
 	else
 	    for(String s=rl.read(); s != null; s=rl.read()) {
 		for(Morpheme m : tg.parse(s))
-		    System.out.println(m.surface+"\t"+m.info);
+		    System.out.println(m.surface+"\t"+m.feature);
 		System.out.println("EOS");
 	    }
     }   
