@@ -12,8 +12,8 @@ public final class Unknown {
 	spaceId = category.category(' ').id;
     }
     
-    public void search(String text, WordDic wdic, List<ViterbiNode> result) {
-	final char ch = text.charAt(0);
+    public void search(String text, int start, WordDic wdic, List<ViterbiNode> result) {
+	final char ch = text.charAt(start);
 	final CharCategory.Category ct = category.category(ch);
 
 	if(result.isEmpty()==false && ct.invoke==false)
@@ -21,10 +21,10 @@ public final class Unknown {
 	
 	final boolean isSpace = ct.id==spaceId;
 	boolean b=true;
-	final int limit = Math.min(text.length(), ct.length);
-	int i=0;
+	final int limit = Math.min(text.length(), ct.length+start);
+	int i=start;
 	for(; i < limit; i++) { 
-	    wdic.searchFromId(ct.id, i+1, isSpace, result);
+	    wdic.searchFromId(ct.id, start, (i-start)+1, isSpace, result);
 	    if(i+1!=limit &&
 	       category.isCompatible(ch, text.charAt(i+1)) == false) {
 		b=false;
@@ -35,10 +35,10 @@ public final class Unknown {
 	if(ct.group && b && i < text.length()) {
 	    for(; i < text.length(); i++)
 		if(category.isCompatible(ch, text.charAt(i)) == false) {
-		    wdic.searchFromId(ct.id, i, isSpace, result);
+		    wdic.searchFromId(ct.id, start, i-start, isSpace, result);
 		    return;
 		}
-	    wdic.searchFromId(ct.id, text.length(), isSpace, result);
+	    wdic.searchFromId(ct.id, start, text.length()-start, isSpace, result);
 	}
     }
 }
\ No newline at end of file
