@@ -7,18 +7,21 @@ public final class ViterbiNode {
     public final int   wordId;
     public final short leftId;
     public final short rightId;
+    public final int   start;
     public final short length;
+
     public final boolean isSpace;
     
-    public ViterbiNode(int wid, short len, short l, short r, boolean space) {
+    public ViterbiNode(int wid, int beg, short len, short l, short r, boolean space) {
 	wordId = wid;
 	leftId = l;
 	rightId =r;
 	length = len;
 	isSpace = space;
+	start = beg;
     }
 
     public static ViterbiNode makeBOSEOS() { 
-	return new ViterbiNode(0,(short)0,(short)0,(short)0,false); 
+	return new ViterbiNode(0,0,(short)0,(short)0,(short)0,false); 
     }
 }
\ No newline at end of file
